@@ -1247,3 +1247,187 @@ def get_rules() :
         }
     )
     return InferenceRules
+
+    def get_owl_el_list():
+        OWL_EL = [
+            "Class Inclusion",
+            "Class Equivalence",
+            "Class Disjointness",
+            "Property Inclusion",
+            "Object Property Inclusion",
+            "Data Property Inclusion",
+            "Property Equivalence",
+            "Object Property Transitivity",
+            "Object Property Reflexivity",
+            "Property Domain",
+            "Property Range",
+            "Functional Data Property",
+            "Same Individual",
+            "Different Individuals",
+            "Class Assertion",
+            #"Positive Object Property Assertion",
+            #"Positive Data Property Assertion",
+            "Negative Object Property Assertion",
+            "Negative Data Property Assertion",
+            "Keys",
+            "Object Some Values From",
+            "Data Some Values From",
+            "Object Has Value",
+            "Data Has Value",
+            "Object Has Self",
+            "Object One Of Membership"
+            "Object One Of Inconsistency",
+            "Data One Of",
+            "Object Intersection Of",
+            "Data Intersection Of",
+        ]
+        return OWL_EL
+
+    def get_owl_rl_list():
+        OWL_RL = [ # Note that only disjoint union and object property reflexitivity are not supported
+            "Class Disjointness",
+            "Object Property Transitivity",
+            "Property Domain",
+            "Property Range",
+            "Functional Data Property",
+            "Functional Object Property",
+            "Object Property Irreflexivity",
+            "Inverse Functional Object Property",
+            "Property Disjointness",
+            "Object Property Symmetry",
+            "Object Property Asymmetry",
+            "Class Inclusion",
+            "Property Inclusion",
+            "Object Property Inclusion",
+            "Data Property Inclusion",
+            "Class Equivalence",
+            "Property Equivalence",
+            "Object Property Inversion",
+            "Same Individual",
+            "Different Individuals",
+            "Class Assertion",
+            #"Positive Object Property Assertion",
+            #"Positive Data Property Assertion",
+            "Negative Object Property Assertion",
+            "Negative Data Property Assertion",
+            "Keys",
+            "Object Some Values From",
+            "Data Some Values From",
+            "Object Has Self",
+            "Object Has Value",
+            "Data Has Value",
+            "Object One Of Membership"
+            "Object One Of Inconsistency",
+            "Data One Of",
+            "Object All Values From",
+            "Data All Values From",
+            "Object Max Cardinality",
+            "Object Min Cardinality",
+            "Object Exact Cardinality",
+            "Object Qualified Max Cardinality",
+            "Object Qualified Min Cardinality",
+            "Object Qualified Exact Cardinality",
+            "Data Max Cardinality",
+            "Data Min Cardinality",
+            "Data Exact Cardinality",
+            "Data Qualified Max Cardinality",
+            "Data Qualified Min Cardinality",
+            "Data Qualified Exact Cardinality",
+            "Datatype Restriction"
+            "Object Union Of"
+            "Data Union Of"
+        ]
+        return OWL_RL
+
+    def get_owl_ql_list():
+        OWL_QL = [
+            "Class Inclusion",
+            "Class Equivalence",
+            "Class Disjointness",
+            "Object Property Inversion",
+            "Property Inclusion",
+            "Property Domain",
+            "Property Range",
+            "Property Disjointness",
+            "Object Property Symmetry",
+            "Object Property Reflexivity",
+            "Object Property Irreflexivity",
+            "Object Property Asymmetry",
+            "Different Individuals",
+            "Class Assertion",
+            #"Positive Object Property Assertion",
+            #"Positive Data Property Assertion"
+            "Object Complement Of",
+            "Object Property Complement Of",
+            "Data Property Complement Of",
+        ]
+        return OWL_QL
+
+    def get_owl_dl_list():
+        OWL_DL =[
+            "Class Disjointness",
+            "Object Property Transitivity",
+            "Property Domain",
+            "Property Range",
+            "Functional Data Property",
+            "Functional Object Property",
+            "Object Property Irreflexivity",
+            "Inverse Functional Object Property",
+            "Property Disjointness",
+            "Object Property Symmetry",
+            "Object Property Asymmetry",
+            "Object Property Reflexivity",
+            "Class Inclusion",
+            "Property Inclusion",
+            "Individual Inclusion",
+            "Object Property Inclusion",
+            "Data Property Inclusion",
+            "Class Equivalence",
+            "Property Equivalence",
+            "Object Property Inversion",
+            "Object Complement Of",
+            "Same Individual",
+            "All Different Individuals",
+            "All Disjoint Classes",
+            "All Disjoint Properties",
+            "Data Complement Of",
+            "Data Property Complement Of",
+            "Different Individuals",
+            "Class Assertion",
+            #"Positive Object Property Assertion",
+            #"Positive Data Property Assertion",
+            "Negative Object Property Assertion",
+            "Negative Data Property Assertion",
+            "Keys",
+            "Object Some Values From",
+            "Data Some Values From",
+            "Object Has Self",
+            "Object Has Value",
+            "Data Has Value",
+            "Object Property Complement Of",
+            "Object One Of Membership",
+            "Object One Of Inconsistency",
+            "Data One Of",
+            "Object All Values From",
+            "Data All Values From",
+            "Object Max Cardinality",
+            "Object Min Cardinality",
+            "Object Exact Cardinality",
+            "Object Qualified Max Cardinality",
+            "Object Qualified Min Cardinality",
+            "Object Qualified Exact Cardinality",
+            "Data Max Cardinality",
+            "Data Min Cardinality",
+            "Data Exact Cardinality",
+            "Data Qualified Max Cardinality",
+            "Data Qualified Min Cardinality",
+            "Data Qualified Exact Cardinality",
+            "Datatype Restriction",
+            "Data Union Of",
+            "Disjoint Union",
+            "Object Union Of",
+            "Object Property Chain Inclusion",
+            "Object Intersection Of",
+            "Data Intersection Of"
+        ] # Also need minInclusive, maxInclusive <-- included in Datatype restriction but is this enough?
+        return OWL_DL
